Cube Objects
============

.. toctree::
   :caption: API Reference
   :maxdepth: 2

Cube
----

.. autoclass:: cr.cube.cube.Cube
    :members:

.. toctree::

CubeSet
-------

.. autoclass:: cr.cube.cube.CubeSet
    :members:

.. toctree::
